#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 digits
version:              0.3.2
visibility:           public
id:                   digits-0.3.2-HVKFJ3uDyuF7Jbd56SZGP6
key:                  digits-0.3.2-HVKFJ3uDyuF7Jbd56SZGP6
license:              BSD-3-Clause
copyright:            (c) 2009-2025 Henry Bucklow, (c) 2016 Charlie Harvey
maintainer:           opensource@elsie.org.uk
author:               Henry Bucklow
synopsis:             Converts integers to lists of digits and back.
description:
    Converts integers to lists of digits and back. Supports arbitrary bases.

category:             Data
abi:                  5b607bc3b947c6fcdf35ed8ddb04c36d
exposed:              True
exposed-modules:      Data.Digits
import-dirs:          /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-digits
hs-libraries:         HSdigits-0.3.2-HVKFJ3uDyuF7Jbd56SZGP6
depends:
    QuickCheck-2.15.0.1-5Y9HZXtqNX41xwYMFzmoSZ base-4.18.2.1

haddock-interfaces:   /usr/share/doc/haskell-digits/html/digits.haddock
haddock-html:         /usr/share/doc/haskell-digits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

